using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.DB.Request;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Request.DBRequest;
using WingInterfaceLibrary.Result;
using WingInterfaceLibrary.DTO.Courses;


namespace WingInterfaceLibrary.Interface.DBInterface
{
    /// <summary>
    /// 课程数据库服务
    /// </summary>
    public interface ICourseDBService
    {

        /// <summary>
        /// 创建新课程
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> CreateCourseAsync(CreateCourseDBRequest request);

        /// <summary>
        /// 查询课程记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<CourseInfoDetailDTO> FindCourseByCodeAsync(FindCourseByCodeDBRequest request);

        /// <summary>
        /// 查询课程列表分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<BaseCourseInfoDTO>> FindCoursePagesAsync(FindCoursePagesDBRequest request);

        /// <summary>
        /// 删除课程记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteCourseByCodeAsync(DeleteCourseByCodeDBRequest request);

        /// <summary>
        /// 更新课程记录
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateCourseAsync(UpdateCourseDBRequest request);

        /// <summary>
        /// 查询学生课程列表分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<BaseCourseInfoDTO>> FindStudentInCoursePagesAsync(FindStudentCoursePagesDBRequest request);
      
        /// <summary>
        /// 更新课程状态
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateCourseStatusAsync(UpdateCourseStatusDBRequest request);

    }
}