
using System.Collections.Generic;
using System.Threading.Tasks;
using WingInterfaceLibrary.DTO.Education;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Request.DBRequest;
using WingInterfaceLibrary.Request.Education;
using WingInterfaceLibrary.Result;
using WingInterfaceLibrary.DB.Request;

namespace WingInterfaceLibrary.Interface.DBInterface
{
    /// <summary>
    /// 教培DB服务
    /// </summary>
    public interface IEducationDBService
    {
        /// <summary>
        /// 获取标签列表
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<IList<CourseLabelDTO>> GetCourseLabelsDBAsync(QueryCourseLabelListRequest request);

        /// <summary>
        /// 获取标签列表【可获取子标签】
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<IList<CourseLabelDTO>> GetCourseLabelDBByCodesAsync(QueryCourseLabelDBRequest request);

        /// <summary>
        ///新增标签
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> AddCourseLabelDBAsync(CourseLabelRequest request);

        /// <summary>
        /// 修改标签
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> UpdateCourseLabelDBAsync(CourseLabelRequest request);

        /// <summary>
        /// 通过code删除标签
        /// </summary> 
        /// <param name="code">标签code</param>
        /// <param name="labelType">标签类型</param>
        /// <returns></returns>
        Task<bool> DeleteCourseLabelDBByCodeAsync(string code, LabelTypeEnum labelType);

        /// <summary>
        /// 客户端根据创建人获取创建的用户组
        /// </summary> 
        /// <param name="creatorCode">创建人code</param>
        /// <returns></returns>
        Task<IList<UserGroupDTO>> GetUserGroupListsDBByCreatorCodeAsync(string creatorCode);

        /// <summary>
        /// 查询用户组分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<UserGroupDTO>> FindUserGroupsPagesDBAsync(QueryUserGroupPageRequest request);

        /// <summary>
        /// 根据用户组和用户code查询用户组信息
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<UserGroupDTO> FindUserGroupsByGroupCodeDBAsync(string userGroupCode, string studentKeyword);

        /// <summary>
        /// 新增用户组
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> AddUserGroupDBAsync(UserGroupRequest request);

        /// <summary>
        /// 修改用户组
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> UpdateUserGroupDBAsync(UserGroupRequest request);

        /// <summary>
        /// 删除用户组
        /// </summary> 
        /// <param name="code">用户组code</param>
        /// <returns></returns>
        Task<bool> DeleteUserGroupDBByCodeAsync(string code);

        /// <summary>
        /// 用户组新增用户
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns></returns>
        Task<bool> AddStudentsByGroupCodeDBAsync(UserGroupRequest request);

        /// <summary>
        /// 用户组移除用户
        /// </summary>
        /// <param name="userGroupCode">用户组code</param>
        /// <param name="studentCodes">学员code列表</param>
        /// <returns></returns>
        Task<bool> RemoveStudentsByGroupCodeDBAsync(string userGroupCode, IList<string> studentCodes);

        /// <summary>
        /// 新增试卷
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> AddExaminationPaperAsync(AddExaminationPaperDBRequest request);

        /// <summary>
        /// 删除试卷
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> DeleteExaminationPaperAsync(DeleteExaminationPaperDBRequest request);

        /// <summary>
        /// 修改试卷
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<bool> UpdateExaminationPaperAsync(UpdateExaminationPaperDBRequest request);

        /// <summary>
        /// 查询试卷
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<ExaminationPaperDTO> GetExaminationPaperAsync(GetExaminationPaperDBRequest request);

        /// <summary>
        /// 查询试卷分页
        /// </summary>
        /// <param name="request"></param>
        /// <returns></returns>
        Task<PageResult<ExaminationPaperDTO>> GetExaminationPaperPagesAsync(GetExaminationPaperPagesDBRequest request);
    }
}