using System.Collections.Generic;
using WingInterfaceLibrary.Enum;
using WingInterfaceLibrary.Enum.NotificationEnum;
using WingInterfaceLibrary.Notifications;

namespace WingInterfaceLibrary.LiveConsultation
{
    /// <summary>
    /// 开始会诊通知到设备端
    /// </summary>
    /// <notificationDocFirstDirectory>通知服务</notificationDocFirstDirectory>
    /// <notificationDocSecondDirectory>设备端</notificationDocSecondDirectory>
    ///<notificationDocThirdDirectory>会诊</notificationDocThirdDirectory>
    public class InviteLiveConsultationToDeviceNotification : NotificationDTO
    {
        /// <summary>
        /// 通知类型枚举 开始会诊的通知
        /// </summary>
        /// <value>14</value>
        public override NotificationTypeEnum NotificationType => NotificationTypeEnum.InviteLiveConsultationToDeviceNotification;
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

        /// <summary>
        /// 房间号码
        /// </summary>
        /// <value>1</value>
        public int RoomNo { get; set; }

        /// <summary>
        /// 设备编码
        /// </summary>
        /// <value>UserDO_123456789</value>
        public string DeviceCode { get; set; } = string.Empty;

        /// <summary>
        /// Sdk APP Id
        /// </summary>
        /// <value>2</value>
        public int AppId { get; set; }

        /// <summary>
        /// 用户签名
        /// </summary>
        /// <value>123456</value>
        public string UserSign { get; set; } = string.Empty;

        /// <summary>
        /// 是否把多路视屏合流
        /// </summary>
        /// <value>true</value>
        public bool MergedChannel { get; set; }
        /// <summary>
        /// 合流的画面宽度
        /// </summary>
        /// <value>1920</value>
        public int MergedVideoOutputWidth { get; set; }

        /// <summary>
        /// 合流的画面高度
        /// </summary>
        /// <value>1080</value>
        public int MergedVideoOutputHeight { get; set; }

        /// <summary>
        /// 多路画面时，设备输出信息
        /// </summary>
        /// <value></value>
        public IList<VideoDeviceOutputInfo> VideoDeviceOutputList { get; set; }
    }
    /// <summary>
    /// 输出画面集合
    /// </summary>
    public class VideoDeviceOutputInfo
    {
        /// <summary>
        /// 设备Id（比如超声机唯一码，用来表示这是超声机画面）
        /// </summary>
        /// <value>321</value>
        public string VideoDeviceId { get; set; }

        /// <summary>
        /// 视屏画面设备来源的类型（设备主屏或摄像头）
        /// </summary>
        /// <value>1</value>
        public VideoDeviceSourceTypeEnum VideoDeviceSourceType { get; set; }

        /// <summary>
        /// 设备设置的画面宽度
        /// </summary>
        /// <value>1920</value>
        public int OutputWidth { get; set; }

        /// <summary>
        /// 设备设置的画面高度
        /// </summary>
        /// <value>1080</value>
        public int OutputHeight { get; set; }

        /// <summary>
        /// 设备签名
        /// </summary>
        /// <value>SignCode</value>
        public string VideoDeviceSign { get; set; } = string.Empty;
    }
}